==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/InstanceStateChange.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>instanceStateChange complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="instanceStateChange">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="currentState" type="{http://cloud.ws.clustercontrol.com}instanceStateKind" minOccurs="0"/>
 *         &lt;element name="instanceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="previousState" type="{http://cloud.ws.clustercontrol.com}instanceStateKind" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "instanceStateChange", propOrder = {
    "currentState",
    "instanceId",
    "previousState"
})
public class InstanceStateChange {

    protected InstanceStateKind currentState;
    protected String instanceId;
    protected InstanceStateKind previousState;

    /**
     * currentStatevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link InstanceStateKind }
     *     
     */
    public InstanceStateKind getCurrentState() {
        return currentState;
    }

    /**
     * currentStatevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceStateKind }
     *     
     */
    public void setCurrentState(InstanceStateKind value) {
        this.currentState = value;
    }

    /**
     * instanceIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceId() {
        return instanceId;
    }

    /**
     * instanceIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceId(String value) {
        this.instanceId = value;
    }

    /**
     * previousStatevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link InstanceStateKind }
     *     
     */
    public InstanceStateKind getPreviousState() {
        return previousState;
    }

    /**
     * previousStatevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceStateKind }
     *     
     */
    public void setPreviousState(InstanceStateKind value) {
        this.previousState = value;
    }

}

==> CloudClientStandardAWS_v2.0.3.zip: com/clustercontrol/ws/cloud/InstanceStateChange.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>instanceStateChange complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="instanceStateChange">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="currentState" type="{http://cloud.ws.clustercontrol.com}instanceStateKind" minOccurs="0"/>
 *         &lt;element name="instanceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="previousState" type="{http://cloud.ws.clustercontrol.com}instanceStateKind" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "instanceStateChange", propOrder = {
    "currentState",
    "instanceId",
    "previousState"
})
public class InstanceStateChange {

    protected InstanceStateKind currentState;
    protected String instanceId;
    protected InstanceStateKind previousState;

    /**
     * currentStateプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link InstanceStateKind }
     *     
     */
    public InstanceStateKind getCurrentState() {
        return currentState;
    }

    /**
     * currentStateプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceStateKind }
     *     
     */
    public void setCurrentState(InstanceStateKind value) {
        this.currentState = value;
    }

    /**
     * instanceIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceId() {
        return instanceId;
    }

    /**
     * instanceIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceId(String value) {
        this.instanceId = value;
    }

    /**
     * previousStateプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link InstanceStateKind }
     *     
     */
    public InstanceStateKind getPreviousState() {
        return previousState;
    }

    /**
     * previousStateプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link InstanceStateKind }
     *     
     */
    public void setPreviousState(InstanceStateKind value) {
        this.previousState = value;
    }

}
